﻿$(document).ready(function () {
    document.body.addEventListener("click", function (event) {
        let dropdowns = document.querySelectorAll(".dropdown-container");
        for (let item of dropdowns) {
            if (item.contains(event.target))
                return;
        }
        if (event.target.classList.contains("ui-icon-circle-triangle-e")
            || event.target.classList.contains("ui-icon-circle-triangle-w")
            || event.target.classList.contains("ui-datepicker-prev")
            || event.target.classList.contains("ui-datepicker-next"))
            return
        document.querySelectorAll('table.data-grid').forEach(item => {
            item.classList.remove('filter-is-opened')
        })
        dropdowns.forEach(item => {
            item.classList.remove("visible")
        })
    })
})

function initDropdown(ref, columnId, filterBtn, dropdownId, datepickerStartId, datepickerEndId, datepickerStart, datepickerEnd, current_locale, maxRangeInDays = 0) {
    initDatepicker(ref, datepickerStartId, datepickerEndId, datepickerStart, datepickerEnd, current_locale, maxRangeInDays)
    let dropdown = document.getElementById(dropdownId);
    document.getElementById(filterBtn)?.addEventListener("click", function (event) {
        if (dropdown?.contains(event.target))
            return
        ref?.invokeMethodAsync('clearFilter')
        if (!dropdown?.classList.contains("visible")) {
            document.querySelectorAll('table.data-grid').forEach(item => {
                if (item.contains(dropdown)) {
                    item.classList.add('filter-is-opened')
                    item.querySelectorAll('th').forEach(th => {
                        th.classList.remove('current-column')
                    })
                    document.getElementById(columnId).classList.add('current-column')
                }
            })
        } else {
            document.querySelectorAll('table.data-grid').forEach(item => {
                item.classList.remove('filter-is-opened')
            })
        }
        event.preventDefault();
        event.stopPropagation();
        let dropdowns = document.querySelectorAll(".dropdown-container");
        dropdowns?.forEach(item => {
            if (item.id !== dropdownId)
                item.classList.remove("visible")
        })
        dropdown?.classList.toggle("visible")
    })
}

function hideDropdown(dropdownId) {
    document.querySelectorAll('table.data-grid').forEach(item => {
        item.classList.remove('filter-is-opened')
    })
    document.getElementById(dropdownId).classList.remove("visible")
}

function initDatepicker(ref, datepickerStartId, datepickerEndId, datepickerStart, datepickerEnd, current_locale, maxRangeInDays = 0){
    let dateFormat = "dd/mm/yyyy",
        from = $("#" + datepickerStartId),
        to = $("#" + datepickerEndId)
    let maxDate = new Date();
    let minDate = new Date();
    minDate.setDate(maxDate.getDate() - maxRangeInDays);
    if (maxRangeInDays === 0)
        minDate = null
    $.datepicker.setDefaults($.datepicker.regional[current_locale]);

    from.datepicker({
        defaultDate: new Date(),
        changeMonth: true,
        numberOfMonths: 1,
        dateFormat: dateFormat,
        changeYear: true,
        firstDay: 1,
        minDate: minDate,
        maxDate: maxDate
    })
        .on("change", function () {
            refreshDatepicker(datepickerStartId, datepickerEndId, from.datepicker("getDate"), to.datepicker("getDate"))
            ref?.invokeMethodAsync('setStartDate', getDate(this))
        })   
    to.datepicker({
        defaultDate: new Date(),
        changeMonth: true,
        numberOfMonths: 1,
        dateFormat: dateFormat,
        changeYear: true,
        firstDay: 1,
        minDate: datepickerStart != null ? new Date(datepickerStart) : null
    })
        .on("change", function () {
            refreshDatepicker(datepickerStartId, datepickerEndId, from.datepicker("getDate"), to.datepicker("getDate"))
            ref?.invokeMethodAsync('setEndDate', getDate(this))
        });

    function getDate(element) {
        let date;
        try {
            date = $.datepicker.parseDate(dateFormat, element.value).toLocaleString("en-US");
        } catch (error) {
            date = null;
        }

        return date;
    }
}

function refreshDatepicker(datepickerStartId, datepickerEndId, datepickerStart, datepickerEnd) {
    let from = $("#" + datepickerStartId),
        to = $("#" + datepickerEndId)
    from.datepicker("option", "maxDate", datepickerEnd != null ? ((new Date(datepickerEnd).getTime() > new Date().getTime()) ? new Date() : new Date(datepickerEnd)) : new Date());
    to.datepicker("option", "minDate", datepickerStart != null ? new Date(datepickerStart) : null);
    from.datepicker('setDate', datepickerStart != null ? ((new Date(datepickerStart).getTime() > new Date().getTime()) ? new Date() : new Date(datepickerStart)) : new Date());
    to.datepicker('setDate', datepickerEnd != null ? new Date(datepickerEnd) : null);
    if (datepickerStart == null)
        from.find(".ui-state-active").removeClass("ui-state-active");
    if (datepickerEnd == null)
        to.find(".ui-state-active").removeClass("ui-state-active");
}
function scrollToFragment(row) {
    var element = document.getElementsByClassName(row);
    if (element.length < 1)
        return;

    element[0].parentNode.scrollTop = element.offsetTop;
}
